Changelog
=========


v0.1a0 (2024-07-17)
-------------------

Release commit(s)
~~~~~~~~~~~~~~~~~
- Release v0.1a0dev0 → v0.1a0. [Forge of Absurd Ducks]

Gitlab task(s)
~~~~~~~~~~~~~~
- Add documentation URL to README. [Quacktor AI]
- Add graphviz tests requirements. [Quacktor AI]
- Remove docker image build & associated files. [Quacktor AI]

  - Also, improve tests for debugging in CI/CD
- Init from advanced quackamollie prototype. [Quacktor AI]


